---
title: <span class="badge builder"></span> CanvasOptionsRoot
---
# <span class="badge builder"></span> CanvasOptionsRoot

## Constructor

```python
CanvasOptionsRoot()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.CanvasOptionsRoot
```

### <span class="badge object-method"></span> elements

The list of canvas elements attached to the root element

```python
def elements(elements: list[cogbuilder.Builder[canvas.CanvasElementOptions]]) -> typing.Self
```

### <span class="badge object-method"></span> name

Name of the root element

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CanvasOptionsRoot](./object-CanvasOptionsRoot.md)
